@@ -21,7 +21,7 @@
 #include "errorwidget.h"
 #include "preferences.h"
 
-#include <KIcon>
+#include <QIcon>
 
 
 namespace Kigo {
@@ -31,8 +31,7 @@ ErrorWidget::ErrorWidget(QWidget *parent)
 {
     setupUi(this);
 
-    configureButton->setIcon(KIcon( QLatin1String( "configure" )));
-    //QPixmap errorPixmap = KIcon( QLatin1String( "dialog-error" )).pixmap(errorLabel->height(), errorLabel->height());
+    configureButton->setIcon(QIcon::fromTheme( QStringLiteral( "configure" )));
 }
 
 void ErrorWidget::on_configureButton_clicked()
@@ -41,5 +40,3 @@ void ErrorWidget::on_configureButton_clicked()
 }
 
 } // End of namespace Kigo
-
-#include "moc_errorwidget.cpp"
